Crate pg_srv

Crate pg_srv 

Bindings for emulating a PostgreSQL server (protocol v3). You can find overview of the protocol at https://www.postgresql.org/docs/10/protocol.html

Re-exports

pub use buffer::*;
pub use error::*;
pub use extended::*;
pub use pg_type::*;
pub use values::*;

Modules

buffer
Helpers for reading/writing from/to the connection’s socket
error
Protocol error types for PostgreSQL wire protocol
extended
Implementation for Extended Query
pg_type
Meta layer information around pg_type
protocol
Implementation of PostgreSQL protocol. Specification for all frontend/backend messages: https://www.postgresql.org/docs/14/protocol-message-formats.html Message Data Types: https://www.postgresql.org/docs/14/protocol-message-types.html
values
PostgreSQL value types for wire protocol

Traits

FromProtocolValue
This trait explains how to decode values from the protocol It’s used in the Bind message
ToProtocolValue
This trait explains how to encode values to the protocol format