Module buffer

Module buffer 

Helpers for reading/writing from/to the connection’s socket

Structs

MessageTagParserDefaultImpl

Traits

MessageTagParser

Functions

read_contents
read_format
read_message
read_string
write_direct
Same as the write_message function, but it doesn’t append header for frame (code + size).
write_message
Write single F message with frame’s headers to the writer. As with the function write_messages, *partial_write is set for graceful shutdown attempts with partial writes. Upon a successful write, it is left empty.
write_messages
Write multiple F messages with frame’s headers to the writer. The variable *partial_write is set for graceful shutdown attempts with partial writes. Upon a successful write, it is left empty.
write_string