Module error

Module error 

Protocol error types for PostgreSQL wire protocol

Enums

ProtocolError
Protocol error abstract of handled/unhandled errors, it should not handle any kind of business logic errors TODO: Migrate back to thiserror crate, when Rust will stabilize feature(error_generic_member_access)