ProtocolError

Enum ProtocolError 

pub enum ProtocolError {
    IO {
        source: Error,
        backtrace: Backtrace,
    },
    ErrorResponse {
        source: ErrorResponse,
        backtrace: Backtrace,
    },
}
Protocol error abstract of handled/unhandled errors, it should not handle any kind of business logic errors TODO: Migrate back to thiserror crate, when Rust will stabilize feature(error_generic_member_access)

Variants



IO

Fields

source: Error
backtrace: Backtrace


ErrorResponse

Fields

backtrace: Backtrace

Implementations

Source

impl ProtocolError

pub fn backtrace(&self) -> Option<&Backtrace>

Return Backtrace from any variant of Enum

pub fn to_error_response(self) -> ErrorResponse

Converts Error to protocol::ErrorResponse which is usefully for writing response to the client