pub struct Parse {
pub name: String,
pub query: String,
pub param_types: Vec<u32>,
}Expand description
(F) Extended Query. Contains a textual query string, optionally some information about data types of parameter placeholders, and the name of a destination prepared-statement object (an empty string selects the unnamed prepared statement)
The response is either ParseComplete or ErrorResponse.
Fields
name: StringThe name of the prepared statement. Empty string is used for unamed statements
query: StringSQL query with placeholders ($1)
param_types: Vec<u32>Trait Implementations
Sourceimpl Deserialize for Parse
impl Deserialize for Parse
impl StructuralPartialEq for Parse