pub type DateValue = NaiveDate;Aliased Type
pub struct DateValue { /* private fields */ }Trait Implementations
Sourceimpl FromProtocolValue for DateValue
impl FromProtocolValue for DateValue
Sourcefn from_text(raw: &[u8]) -> Result<Self, ProtocolError>
fn from_text(raw: &[u8]) -> Result<Self, ProtocolError>
Decodes raw value to native type in text format
Sourcefn from_binary(raw: &[u8]) -> Result<Self, ProtocolError>
fn from_binary(raw: &[u8]) -> Result<Self, ProtocolError>
Decodes raw value to native type in binary format
fn from_protocol(raw: &[u8], format: Format) -> Result<Self, ProtocolError>where
Self: Sized,
Sourceimpl ToProtocolValue for DateValue
impl ToProtocolValue for DateValue
Sourcefn to_text(&self, buf: &mut BytesMut) -> Result<(), ProtocolError>
fn to_text(&self, buf: &mut BytesMut) -> Result<(), ProtocolError>
Converts native type to raw value in text format
Sourcefn to_binary(&self, buf: &mut BytesMut) -> Result<(), ProtocolError>
fn to_binary(&self, buf: &mut BytesMut) -> Result<(), ProtocolError>
Converts native type to raw value in binary format