Helpers for reading/writing from/to the connection’s socket
Structs
Traits
Functions
- read_
contents - read_
format - read_
message - read_
string - write_
direct - Same as the write_message function, but it doesn’t append header for frame (code + size).
- write_
message - Write single F message with frame’s headers to the writer. As with the
function
write_messages,*partial_writeis set for graceful shutdown attempts with partial writes. Upon a successful write, it is left empty. - write_
messages - Write multiple F messages with frame’s headers to the writer. The variable
*partial_writeis set for graceful shutdown attempts with partial writes. Upon a successful write, it is left empty. - write_
string