pub enum CommandComplete {
Select(u32),
Fetch(u32),
Plain(String),
}Expand description
It’s used to describe client that changes was done. The command tag. This is usually a single word that identifies which SQL command was completed. See more variants from sources: https://github.com/postgres/postgres/blob/REL_14_4/src/include/tcop/cmdtaglist.h#L27
Variants
Implementations
Sourceimpl CommandComplete
impl CommandComplete
pub fn new_selection(is_select: bool, rows: u32) -> Self